@@ -1,5 +1,5 @@
 package Devel::FindPerl;
-$Devel::FindPerl::VERSION = '0.013';
+$Devel::FindPerl::VERSION = '0.014';
 use strict;
 use warnings;
 
@@ -69,7 +69,7 @@ sub _discover_perl_interpreter {
 	# absolute path of the first successful match.
 	my $exe = $config->get('exe_ext');
 	foreach my $thisperl (@potential_perls) {
-		$thisperl->[0] .= $exe if length $exe and $thisperl->[0] !~ m/\Q$exe$/i;
+		$thisperl->[0] .= $exe if length $exe and $thisperl->[0] !~ m/\Q$exe\E$/i;
 		return $thisperl if -f $thisperl->[0] && perl_is_same(@{$thisperl});
 	}
 
@@ -145,7 +145,7 @@ Devel::FindPerl - Find the path to your perl
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
